@@ -6,16 +6,16 @@ my $ex = new HTML::Expander;
 
 $ex->define_tag( 'main', '<name>',  '<h1><font color=%c>' );
 $ex->define_tag( 'main', '</name>', '</font></h1>' );
-$ex->style_copy( 'new', 'main' );
+$ex->mode_copy( 'new', 'main' );
 $ex->define_tag( 'new', '<h1>',  '<p><h1>' );
 $ex->define_tag( 'new', '<box>',  '<pre>' );
 $ex->define_tag( 'new', '</box>',  '</pre>' );
 
-print $ex->expand( "<style name=new>
-                      <box>(current style is '<var name=!STYLE>')</box>
+print $ex->expand( "<mode name=new>
+                      <box>(current mode is '<var name=!mode>')</box>
                       <name c=#fff>This is me</name>
-                    </style>
-                      <box>(cyrrent style is '<var name=!STYLE>')</box>
+                    </mode>
+                      <box>(cyrrent mode is '<var name=!mode>')</box>
                       <name>empty</name>
                     1.<var name=TEST>
                     2.<var name=TEST set=opala! echo>
